Afrikaans
Akan
Albanian
Amharic
Armenian
Azerbaijani
Basque
Belarusian
Bemba
Bihari
Bosnian
Breton
Bulgarian
Cambodian
Catalan
Cebuano
Cherokee
Chichewa
Corsican
Czech
Esperanto
Estonian
Ewe
Faroese
Filipino
Finnish
Frisian
Ga
Galician
Georgian
German
Guarani
Gujarati
Haitian Creole
Hausa
Hawaiian
Hebrew
Hmong
Icelandic
Igbo
Interlingua
Irish
Javanese
Kannada
Kazakh
Kinyarwanda
Kirundi
Kongo
Krio (Sierra Leone)
Kurdish
Kurdish (Soranรฎ)
Kyrgyz
Laothian
Latin
Latvian
Lingala
Lithuanian
Lozi
Luganda
Luo
Luxembourgish
Macedonian
Malagasy
Maltese
Maori
Mauritian Creole
Moldavian
Mongolian
Myanmar (Burmese)
Montenegrin
Nepali
Nigerian Pidgin
Northern Sotho
Norwegian
Norwegian (Nynorsk)
Occitan
Oriya
Oromo
Pashto
Persian
Punjabi
Quechua
Romanian
Romansh
Runyakitara
Russian
Samoan
Scots Gaelic
Serbo-Croatian
Sesotho
Setswana
Seychellois Creole
Shona
Sindhi
Sinhalese
Slovak
Slovenian
Somali
Sundanese
Tajik
Tamil
Tatar
Telugu
Tigrinya
Tonga
Tshiluba
Tumbuka
Turkmen
Twi
Uighur
Ukrainian
Uzbek
Vietnamese
Welsh
Wolof
Xhosa
Yiddish
Yoruba
Zulu
(birds chirping)
(slow breathing)
(groans softly)
-Aah.
(groans)
-It's like fucking school again. We got so wrecked.
Should have come. It was a good night.
Proper laugh.
โชโช
(exhales)
-Uh, so look, I, um...
I am not gonna be here for the summer.
Yeah.
Like, I can't pay the rent.
Yeah.
And Niall's gonna sublet the room, so...
I'll have to move out.
-When?
-Uh, pretty soon. Next week, maybe.
-So you'll be going back to Sligo, then.
โชโช
CONNELL: I mean, um...
I guess...
I guess you want to see other people, or, uh...
-I guess so. Yeah.
(dishes clattering)
โชโช
โชโช
-MS. NEARY: Connell Waldron. -CONNELL: Ah, Ms. Neary.
-MS. NEARY: Oh, my God. Would ya not call me that?
-Haven't seen you since school.
โชโช
Ah, it's weird seeing ya.
-Good weird. -Mm.
(laughs)
Ooh.
-You're so fucking hard. -(laughs)
-(laughs) What?
Do you wanna come back to my place?
-Oh...
I'm gonna be sick.
-What? -Uh... mm.
Hey, um...
I should go.
(birds chirping)
(thuds)
(birds chirping)
CONNELL: So I guess we should see other people.
-I guess so.
โช
CONNELL: You didn't tell me you were in town.
-Yeah.
(rain pattering)
-I got your text...
when you were home. Feels a bit weird running into you
with no warning or anything. -MARIANNE: Warning? (scoffs)
-You know what I mean.
-I'm just back for the weekend.
It's my father's anniversary mass.
-I'm sorry.
Can I come?
Obviously, if don't want me to I won't, but I'd like to.
-Sorry. -No?
Okay.
You're with Jamie now, I hear.
He always liked ya.
-What about you?
You seeing anyone? -No.
Not at the minute.
-Embracing the single lifestyle? -Yeah.
Yeah, you know me.
-I did once.
(seat belt clicks)
-Look, if you don't want to be friends, that's fine.
I'd just rather know, so we can...
-Course I want to be friends.
-Okay.
-Do you want to come in?
For, like, a tea, or--
-I can't. I've got shopping in the back.
-Thanks for the lift.
(rain pouring)
-Length of days is not what makes age honorable,
nor number of years the true measure of life.
Understanding.
This is man's gray hairs.
Untarnished life.
This is ripe old age.
He has sought to please God,
so God has loved him.
As he was living among sinners,
he has been taken up.
He has been carried off so that evil may not warp his understanding,
or treachery seduce his soul.
For the fascination of evil
throws good things into the shade.
-(indistinct chatter) -(car zooming)
(traffic noises)
(car honks)
(indistinct chatter)
-You didn't need to run.
-Ah, my bus got caught in traffic.
Some protest.
-Got you a coffee.
-Ah, thanks.
How are you feeling about Schols?
-How are you feeling about them, Connell?
-Hmm. How am I feeling about
my entire future being potentially secure, or...
mind-numbingly difficult? Yeah, it's, ah...
...casual.
How's Jamie?
-Be nice if you guys could actually be civil.
-Ah. I'm civil. -Oh.
You could just, like, uh,
try not to intimidate him quite so much.
-(laughs) Are you telling him not to intimidate me?
-(scoffs) As if, Connell.
He's barely my height. -Ah.
I'm not sure intimidation is
strictly limited to height, though. -No?
From where he's standing,
you're the tall guy who used to fuck his girlfriend.
-Right.
Is that how you describe me to all your friends?
The tall guy who fucked you?
-Pretty sure we fucked each other.
We had mutual,
equally involved kind of sex.
It's different.
With Jamie.
-What do you mean?
-Do you want to hear about this?
He's into pain.
Like, inflicting it.
Turns out he's a bit of a sadist.
(Connell chuckles)
-Are you serious?
-Just during sex, that is. Not arguments.
Your face.
-And you're, you're into that,
are ya?
-Yeah.
You're so shocked.
We really don't have to talk about this.
-(inhales) What does he do to ya, specifically?
-Slaps me. Uses a belt.
Things like that.
-Right.
Sounds fucking horrible.
-It's not.
It's just different.
-You never said any of this to me when we were...
-Well, it was different with you.
Things were different.
-Right.
-Didn't have to play any games with you.
It was just real.
With Jamie, I don't know.
It's a bit like I'm acting a part.
I just pretend to feel a certain way.
Like I'm in his power.
But with you, I actually had those feelings.
I'd have done anything you wanted me to.
Anyway...
How are you?
(train rumbling)
(Jamie grunting)
โชโช
(Jamie panting)
(gasps)
โชโช
โชโช
โชโช
โชโช
(crowd applauding)
PROVOST: The English scholars are...
Marion Pickard...
(crowd cheering, applauding)
David Sexton...
(crowd cheering, applauding)
Ashley Tobin...
(excited cheering, applauding)
Connell Waldron...
NIALL: Fucking yes, mate. (laughing)
Fucking right, you absolute fucking nerd.
Fucking five years free tuition, free accommodation.
Five years, you jammy fucker! Unreal, man.
PROVOST: And Mairead Button...
(crowd cheering, applauding)
PROVOST: The history and politics scholar is...
Marianne Sheridan.
(crowd cheering, applauding)
-(Jamie laughs) -Aah!
(chatter and laughter)
(laughing)
-Traveling from west to east is literally like crossing a border
into a completely different city, it's totally surreal.
-I mean, I've been, so, I, uh...
-Yeah, because everyone has been to fucking Berlin, Peggy.
You're making out like you just got back from Syria.
-Marianne's not been to Berlin. I'm explaining for her benefit.
They don't let people from Connacht travel that far.
-(Joanna laughs) -PHILIP: Ooh.
-Extremely hilarious. -Marianne has been to Berlin.
-Does anyone want more food? -SOPHIE: Yeah, it's so good.
-Joanna cooked it. -Yeah, I can make, like, one thing. (laughs)
Anyway, should we do, uh, a fuckin' toast or something
to the cleverest history and politics student
Trinity has ever known?
-JAMIE: Hear, hear. -Stop it.
-Don't mind fuckin' me. -JAMIE: Ooh, we won't.
-Poor Peggy. -It's fine. I never studied.
-(laughter) -To Marianne.
-PHILIP and JOANNA: To Marianne. -PEGGY: To Marianne.
(glasses clinking)
-To the cleverest girl in Trinity.
-Jesus, stop it, please. -(all laughing)
-(phone ringing) -Thank God.
(all chattering)
(phone ringing)
Eat up.
Hello?
Oh. Hi.
(indistinct chatter)
What? Are you okay?
Where are you?
(engine running)
Jesus Christ, Connell.
-I know, it's fine. It's, uh... It's not as bad as it looks.
-Thank you. -DRIVER: Thanks.
(engine roars)
(door squeaks, shuts)
-What happened? -Uh, just this lad.
Asked for my wallet.
I should have handed it over, but I said no,
and he hit me in the face.
I'm fine.
Your phone number was the only one I knew off by heart.
I'm really sorry. I'm really drunk.
-How drunk?
-Ah, well, I've been out
since they announced Schols, so...
-Right. -Mm-hmm.
Do I still have pupils?
-Just about.
They're huge. -Mm.
They always get like that when I see you, anyways.
-Aah. -Mm.
-Mm. You must be drunk.
-How do you mean?
-Jamie's downstairs.
-Oh.
Uh...
Ah, maybe I'll just go back out and get punched in the face.
It really wasn't that bad. -Connell.
-Ah. (laughs)
-Ugh. Fucking lowlife scum.
-What?
-Fucking lowlife scum?
-Well, that's quite the welcome, Jamie.
You know, uh, we can't, uh...
We can't all be the spawn of millionaires.
(all laughing softly)
-Yeah, well, I was talking about the dickhead
who robbed you to buy drugs, obviously. -Drugs?
-Yeah. Well, he's hardly using your cash to buy loaves of bread for his kids.
Be up his nose or in a needle, won't it?
-SOPHIE: Looks pretty bad, Connell. You okay?
-It's not as bad as it looks.
-Okay, I mean, will we get going, or--
-You're such a sweetheart, Peggy.
-He just said he was fine. -I am. Thanks.
-I'll join you in a bit. Get this one cleaned up first.
JAMIE: They stop letting in at 12.
-I'm pretty tired anyways.
You go. Call you tomorrow.
-JAMIE: Right.
If you're sure?
(kisses)
Okay?
-Thanks for dinner, mate.
-PHILIP: Thanks, Marianne. -Thank you. It was delicious.
-SOPHIE: And congratulations again, Marianne.
You, too, Connell.
-JOANNA: Congrats, Connell. -Thanks.
-JOANNA: Feel better. -SOPHIE: Come on, you guys.
(footsteps departing)
-JAMIE: Connell. -Jamie.
(door slams)
(water steaming)
You could have a different boyfriend, you know.
I mean,
guys are consistently falling in love with you,
from what I hear.
-Stop that.
Tea?
-People love ya or hate ya.
-Right.
(clattering)
You don't hate me.
-No.
No, I'm immune to ya.
Because I knew you before, in school.
-When I was ugly and pathetic? -No.
You were never ugly or pathetic.
I'd rather literally anyone else, Marianne.
I'd rather the lad that mugged me was your boyfriend.
-Why do you care?
-Do you love him?
-We don't talk about that, do we?
I thought that stuff was off-limits for us.
-All right. Okay.
You know, I probably should have mentioned this before,
but I've been seeing someone.
Been with her a while. Yeah.
Should have mentioned it before, but then again,
I feel like we've hardly seen each other.
Barely spent any time together, and, uh...
Yeah, her name's Helen Brophy.
I don't know would you know her. She studies medicine.
(clattering)
(Marianne breathing shakily)
-Why were you trying to get me to break up with Jamie?
-No, I'm not.
I'm not. I just want you to be happy is all.
-'Cause you're such a good friend, is it? -Yeah.
Mm-hmm. Yeah. I, I mean, I-- I, I think I...
(sobs)
Jesus. Marianne.
I feel awful. I'm sorry. I should have said it before.
-I don't want to talk to you, Connell. Just leave. (sniffs)
Please, can you just go? -Yeah.
(Marianne sniffles)
(Marianne sobbing)
Look, I'm, uh, really sorry to have to ask.
It's just, I, uh...
I can't get home.
(Marianne sobbing)
Uh, uh...
Would I be able to borrow the money, like you said?
-MARIANNE: Oh, God. (sniffles)
Sorry.
I managed to forget you've been beaten up somehow. I... Yeah.
-Mm.
(door opens)
-Here.
-Uh, thanks.
Um...
You know, uh...
I don't know what happened with us last summer.
Uh, like, when I had to go home and that.
See, I kind of hoped that I would have been able to stay here.
That you would have let me.
Yeah, I, I just, uh... I don't really know
what happened between us, to be honest.
-(sniffles) You said you wanted to see other people.
-No.
-I thought you were breaking up with me.
You never said anything about wanting to stay here. I...
That would have been...
Always.
Obviously.
-Uh...
Right, well, I, I should go. I'm, uh...
Have a good night, Marianne.
("Metroma" by The Sei playing)
โช We brought this on โช
โช Resisting โช
โช Dead or alive โช
โช We're missing โช
โช Don't ask why โช
โช I close my eyes โช
โช Something inside โช
โช Insisting โช
โช Better than God โช
โช Just listen โช
โช Take my time โช
โช This is the place โช
โช I met you โช
โช Say I'm found โช
Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.